@@ -1,7 +1,7 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 from pmb.chroot.init import init, init_keys
-from pmb.chroot.mount import mount, mount_native_into_foreign
+from pmb.chroot.mount import mount, mount_native_into_foreign, remove_mnt_pmbootstrap
 from pmb.chroot.root import root
 from pmb.chroot.user import user
 from pmb.chroot.user import exists as user_exists
